# CDDL HEADER START
#
# The contents of this file are subject to the terms of the
# Common Development and Distribution License (the "License").  
# You may not use this file except in compliance with the License.
#
# You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
# or http://www.opensolaris.org/os/licensing.
# See the License for the specific language governing permissions
# and limitations under the License.
#
# When distributing Covered Code, include this CDDL HEADER in each
# file and include the License file at usr/src/OPENSOLARIS.LICENSE.
# If applicable, add the following below this CDDL HEADER, with the
# fields enclosed by brackets "[]" replaced with your own identifying
# information: Portions Copyright [yyyy] [name of copyright owner]
#
# CDDL HEADER END
#
#
# Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
# Use is subject to license terms.
#
# ident	"@(#)Makefile.cmd	1.31	07/01/12 SMI"
#
# cmd/Makefile.cmd
#
# Definitions common to command source.
#

include $(CODEMGR_WS)/src/sun_avs/Makefile.master

LN=		ln
SH=		sh
TOUCH=		touch

FILEMODE=	0555
LIBFILEMODE=	0444
STATIC=		$(STATPROG:%=%.static)
XPG4=		$(XPG4PROG:%=%.xpg4)

ROOTBIN=	$(ROOT)/usr/bin
ROOTLIB=	$(ROOT)/usr/lib
ROOTSHLIB=	$(ROOT)/usr/share/lib
ROOTSBIN=	$(ROOT)/sbin
ROOTUSRSBIN=	$(ROOT)/usr/sbin
ROOTUSRSBINSTAT=$(ROOT)/usr/sbin/static
ROOTETC=	$(ROOT)/etc
ROOTCCSBIN=	$(ROOT)/usr/ccs/bin
ROOTUSRKVM=	$(ROOT)/usr/kvm
ROOTUSRTOOLS=	$(ROOT)/usr/tools
ROOTXPG4=	$(ROOT)/usr/xpg4
ROOTXPG4BIN=	$(ROOT)/usr/xpg4/bin
ROOTLOCALEDEF=	$(ROOT)/usr/lib/localedef
ROOTCHARMAP=	$(ROOTLOCALEDEF)/charmap
ROOTI18NEXT=	$(ROOTLOCALEDEF)/extensions
ROOTI18NEXT64=	$(ROOTLOCALEDEF)/extensions/$(MACH64)
ROOTBIN32=	$(ROOTBIN)
ROOTBIN64=	$(ROOTBIN)/$(MACH64)
ROOTLIB64=	$(ROOTLIB)/$(MACH64)
ROOTUSRSBIN32=	$(ROOTUSRSBIN)
ROOTUSRSBIN64=	$(ROOTUSRSBIN)/$(MACH64)

ISAEXEC=	$(ROOT)/usr/lib/isaexec

LDLIBS =	-L$(ROOTLIB) $(LDLIBS.cmd)

LDFLAGS.cmd = $(ENVLDFLAGS1) $(ENVLDFLAGS2) $(ENVLDFLAGS3)
#
# Only strip non-DEBUG binaries
$(RELEASE_BUILD)LDFLAGS.cmd += $(STRIPFLAG)
#
# By default, link all PROG statically,
# except for those declared as DYNPROG
LDFLAGS =	-dn $(LDFLAGS.cmd)
$(STATIC) :=	LDFLAGS = $(LDFLAGS.cmd) -dn
$(DYNPROG) :=	LDFLAGS = $(LDFLAGS.cmd) -dy \
			-R /usr/lib:/usr/lib:/usr/lib

LINTFLAGS=	-ax
LINTOUT=	lint.out

ROOTPROG=	$(PROG:%=$(ROOTBIN)/%)
ROOTSHFILES=	$(SHFILES:%=$(ROOTBIN)/%)
ROOTLIBPROG=	$(PROG:%=$(ROOTLIB)/%)
ROOTLIBSHFILES= $(SHFILES:%=$(ROOTLIB)/%)
ROOTSHLIBPROG=	$(PROG:%=$(ROOTSHLIB)/%)
ROOTSBINPROG=	$(PROG:%=$(ROOTSBIN)/%)
ROOTUSRSBINPROG=$(PROG:%=$(ROOTUSRSBIN)/%)
ROOTBOOTPROG=	$(STATPROG:%=$(ROOTSBINSTAT)/%)
ROOTSTATPROG=	$(STATPROG:%=$(ROOTUSRSBINSTAT)/%)
ROOTETCPROG=	$(PROG:%=$(ROOTETC)/%)
ROOTCCSBINPROG=	$(PROG:%=$(ROOTCCSBIN)/%)
ROOTUSRKVMPROG=	$(PROG:%=$(ROOTUSRKVM)/%)
ROOTXPG4PROG=	$(XPG4PROG:%=$(ROOTXPG4BIN)/%)
ROOTLOCALEPROG=	$(PROG:%=$(ROOTLOCALEDEF)/%)
ROOTPROG64=	$(PROG:%=$(ROOTBIN64)/%)
ROOTPROG32=	$(PROG:%=$(ROOTBIN32)/%)
ROOTUSRSBINPROG32=	$(PROG:%=$(ROOTUSRSBIN32)/%)
ROOTUSRSBINPROG64=	$(PROG:%=$(ROOTUSRSBIN64)/%)

$(ROOTBIN)/%: %
	$(INS.file)

$(ROOTLIB)/%: %
	$(INS.file)

$(ROOTBIN64)/%: %
	$(INS.file)

$(ROOTLIB64)/%: %
	$(INS.file)

$(ROOTBIN32)/%: %
	$(INS.file)

$(ROOTSHLIB)/%: %
	$(INS.file)

$(ROOTSBIN)/%: %
	$(INS.file)

$(ROOTUSRSBIN)/%: %
	$(INS.file)

$(ROOTUSRSBIN32)/%: %
	$(INS.file)

$(ROOTUSRSBIN64)/%: %
	$(INS.file)

$(ROOTETC)/%: %
	$(INS.file)

$(ROOTCCSBIN)/%: %
	$(INS.file)

$(ROOTUSRKVM)/%: %
	$(INS.file)

$(ROOTUSRSBINSTAT)/%: %.static
	$(INS.rename)

$(ROOTXPG4BIN)/%: %.xpg4
	$(INS.rename)

$(ROOTLOCALEDEF)/%: %
	$(INS.file)

$(ROOTCHARMAP)/%: %
	$(INS.file)

$(ROOTI18NEXT)/%: %
	$(INS.file)

$(ROOTI18NEXT64)/%: %
	$(INS.file)

# build rule for statically linked programs with single source file.
%.static: %.c
	$(LINK.c) -o $@ $< $(LDLIBS)
	$(POST_PROCESS)

%.xpg4: %.c
	$(LINK.c) -o $@ $< $(LDLIBS)
	$(POST_PROCESS)

# Define the majority text domain in this directory.
TEXT_DOMAIN= SUNW_ISS_CMD	
DCMSGDOMAIN= $(MSGROOT)/LC_TIME/$(TEXT_DOMAIN)

CLOBBERFILES += $(XPG4) $(STATIC) $(DCFILE)

# Build flags
OPTION_DEFS = -D$(BUILD_ENV) \
		-D_$(BUILD_SYS)_MINOR=$(BUILD_MINOR) \
		-D_$(BUILD_SYS)_MICRO=$(BUILD_MICRO) \
		-DNSC_MULTI_TERABYTE \
		-DBUILD_REV_STR='"$(RELEASE)"' \
		-DISS_VERSION_STR='"$(VERSION)_$(RELEASE)"' \
		-D_VERSION_='"$(VERSION)_$(RELEASE) $(RELEASE_DATE)"' \
		-DBUILD_DATE_STR='"$(RELEASE_DATE)"' \
		$(ISS_VERSION_DEFS)

# Debugging level
$(NOT_RELEASE_BUILD)DEBUG = -DDEBUG -g
LINT_DEBUG = -DDEBUG

# Include paths
CFLAGS		+= $(INC_PATH) $(OPTION_DEFS) $(DEBUG)
LINTFLAGS	+= $(INC_PATH) $(OPTION_DEFS) $(LINT_DEBUG)

# This flag is being added only for SCO (x86) compatibility
i386_SPFLAG=    -D_iBCS2
sparc_SPFLAG=

iBCS2FLAG = $($(MACH)_SPFLAG)
